@@ -11,13 +11,17 @@ require DynaLoader;
 @EXPORT = qw( );
 @EXPORT_OK = qw (usleep sleep ualarm alarm gettimeofday time tv_interval
 		 getitimer setitimer nanosleep clock_gettime clock_getres
+		 clock clock_nanosleep
 		 CLOCK_HIGHRES CLOCK_MONOTONIC CLOCK_PROCESS_CPUTIME_ID
-		 CLOCK_REALTIME CLOCK_THREAD_CPUTIME_ID CLOCK_TIMEOFDAY
+		 CLOCK_REALTIME CLOCK_SOFTTIME CLOCK_THREAD_CPUTIME_ID
+		 CLOCK_TIMEOFDAY CLOCKS_PER_SEC
 		 ITIMER_REAL ITIMER_VIRTUAL ITIMER_PROF ITIMER_REALPROF
+		 TIMER_ABSTIME
 		 d_usleep d_ualarm d_gettimeofday d_getitimer d_setitimer
-		 d_nanosleep d_clock_gettime d_clock_getres);
+		 d_nanosleep d_clock_gettime d_clock_getres
+		 d_clock d_clock_nanosleep);
 	
-$VERSION = '1.83';
+$VERSION = '1.84';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -42,11 +46,13 @@ sub AUTOLOAD {
 sub import {
     my $this = shift;
     for my $i (@_) {
-	if (($i eq 'clock_getres'  && !&d_clock_getres)  ||
-	    ($i eq 'clock_gettime' && !&d_clock_gettime) ||
-	    ($i eq 'nanosleep'     && !&d_nanosleep)     ||
-	    ($i eq 'usleep'        && !&d_usleep)        ||
-	    ($i eq 'ualarm'        && !&d_ualarm)) {
+	if (($i eq 'clock_getres'    && !&d_clock_getres)    ||
+	    ($i eq 'clock_gettime'   && !&d_clock_gettime)   ||
+	    ($i eq 'clock_nanosleep' && !&d_clock_nanosleep) ||
+	    ($i eq 'clock'           && !&d_clock)           ||
+	    ($i eq 'nanosleep'       && !&d_nanosleep)       ||
+	    ($i eq 'usleep'          && !&d_usleep)          ||
+	    ($i eq 'ualarm'          && !&d_ualarm)) {
 	    require Carp;
 	    Carp::croak("Time::HiRes::$i(): unimplemented in this platform");
 	}
@@ -77,7 +83,7 @@ Time::HiRes - High resolution alarm, sleep, gettimeofday, interval timers
 =head1 SYNOPSIS
 
   use Time::HiRes qw( usleep ualarm gettimeofday tv_interval nanosleep
-		      clock_gettime clock_getres );
+		      clock_gettime clock_getres clock_nanosleep clock );
 
   usleep ($microseconds);
   nanosleep ($nanoseconds);
@@ -108,6 +114,10 @@ Time::HiRes - High resolution alarm, sleep, gettimeofday, interval timers
   $realtime   = clock_gettime(CLOCK_REALTIME);
   $resolution = clock_getres(CLOCK_REALTIME);
 
+  clock_nanosleep(CLOCK_REALTIME, 1.5, TIMER_ABSTIME);
+
+  my $ticktock = clock();
+
 =head1 DESCRIPTION
 
 The C<Time::HiRes> module implements a Perl interface to the
@@ -156,8 +166,10 @@ seconds like C<Time::HiRes::time()> (see below).
 
 Sleeps for the number of microseconds (millionths of a second)
 specified.  Returns the number of microseconds actually slept.  Can
-sleep for more than one second, unlike the C<usleep> system call. See
-also C<Time::HiRes::usleep()> and C<Time::HiRes::sleep()>.
+sleep for more than one second, unlike the C<usleep> system call. Can
+also sleep for zero seconds, which often works like a I<yield>.  See
+also C<Time::HiRes::usleep()>, C<Time::HiRes::sleep()>, and
+C<Time::HiRes::clock_nanosleep()>.
 
 Do not expect usleep() to be exact down to one microsecond.
 
@@ -166,8 +178,9 @@ Do not expect usleep() to be exact down to one microsecond.
 Sleeps for the number of nanoseconds (1e9ths of a second) specified.
 Returns the number of nanoseconds actually slept (accurate only to
 microseconds, the nearest thousand of them).  Can sleep for more than
-one second.  See also C<Time::HiRes::sleep()> and
-C<Time::HiRes::usleep()>.
+one second.  Can also sleep for zero seconds, which often works like a
+I<yield>.  See also C<Time::HiRes::sleep()>, C<Time::HiRes::usleep()>,
+and C<Time::HiRes::clock_nanosleep()>.
 
 Do not expect nanosleep() to be exact down to one nanosecond.
 Getting even accuracy of one thousand nanoseconds is good.
@@ -310,7 +323,34 @@ documentation for other possibly supported values.
 Return as seconds the resolution of the POSIX high resolution timer
 specified by C<$which>.  All implementations that support POSIX high
 resolution timers are supposed to support at least the C<$which> value
-of C<CLOCK_REALTIME>,  see L</clock_gettime>.
+of C<CLOCK_REALTIME>, see L</clock_gettime>.
+
+=item clock_nanosleep ( $which, $nanoseconds, $flags = 0)
+
+Sleeps for the number of nanoseconds (1e9ths of a second) specified.
+Returns the number of nanoseconds actually slept (accurate only to
+microseconds, the nearest thousand of them).  The $which is as with
+clock_gettime() and clock_getres().  The flags defaults to zero but it
+can contain C<TIMER_ABSTIME> (must be exported if needed) which means
+that C<$nanoseconds> is not a time interval but instead an absolute
+time.  Can sleep for more than one second.  Can also sleep for zero
+seconds, which often works like a I<yield>.  See also
+C<Time::HiRes::sleep()>, C<Time::HiRes::usleep()>, and
+C<Time::HiRes::nanosleep()>.
+
+Do not expect clock_nanosleep() to be exact down to one nanosecond.
+Getting even accuracy of one thousand nanoseconds is good.
+
+=item clock()
+
+Return as seconds the I<process time> (CPU time) spent by the process
+B<since some arbitrary starting point (era) in the past>.  If you are
+lucky, in your system this arbitrary starting point is the starting
+time of your process.  If not, you have to first store the result of
+a clock() call and then subtract that initial value from all the results
+of the following clock() calls.  These (resulting differences) are
+somewhat like the second value returned by the times() of core Perl,
+but not necessarily identical.
 
 =back
 
@@ -366,6 +406,16 @@ of C<CLOCK_REALTIME>,  see L</clock_gettime>.
   # But how accurate we can be, really?
   my $reso = clock_getres(CLOCK_REALTIME);
 
+  use Time::HiRes qw( clock_nanosleep TIMER_ABSTIME );
+  clock_nanosleep(CLOCK_REALTIME, 1e6);
+  clock_nanosleep(CLOCK_REALTIME, 2e9, TIMER_ABSTIME);
+
+  use Time::HiRes qw( clock );
+  my $clock0 = clock();
+  ... # Do something.
+  my $clock1 = clock();
+  my $clockd = $clock1 - $clock0;
+
 =head1 C API
 
 In addition to the perl API described above, a C API is available for
